# PaperLess Open Marking - [Plom](https://plomgrading.org)

  * A system for giving tests on paper, but marking and returning
    them online.
  * Designed for giving consistent, meaningful feedback to students.
  * [Free/Open Source Software](https://www.gnu.org/licenses/agpl-3.0.en.html)
    written in Python using [Qt](https://pypi.org/project/PyQt5) and other
    components.

<img src="https://plomgrading.org/images/plomclient.png" width="800px" alt="The plom annotation client in action">


## Plom's benefits

  * Respects privacy of student data -- all data stays on your server,
    and markers do not see student name or ID when working.
  * Easy multi-versioned tests -- designed to handle crowded classrooms
    and multi-section courses over multiple days.
  * Simplify logistics and minimizes paper-handling.
  * Free -- Plom is both [Libre](https://en.wikipedia.org/wiki/Gratis_versus_libre#Libre)
    and [Gratis](https://en.wikipedia.org/wiki/Gratis_versus_libre#Gratis).
    No software to buy, and no subscriptions to pay.


## Want to know more?

Take a look at the [plomgrading.org](https://plomgrading.org).
